@@ -6,12 +6,12 @@ from deap import tools
 from deap import base
 import array
 
-meta_hof = pareto.ParetoFront(similar=pareto.similar, similar_fit=pareto.similar_fit_meta(cache),
+meta_hof = pareto.ParetoFrontMeta(similar=pareto.similar, similar_fit=pareto.similar_fit_meta(cache),
                                           slice_object=cache.meta_slice)
 
 creator.create("FitnessMaxMeta", base.Fitness, weights=[1.0, 1.0, 1.0, -1.0, -1.0])
 creator.create("IndividualMeta", array.array, typecode="d", fitness=creator.FitnessMaxMeta, strategy=None,
-                   csv_line=None)
+                   csv_line=None, best=None)
 
 toolbox = base.Toolbox()
 
