@@ -73,7 +73,7 @@ def log_likelihood(individual, json_path):
     scores, csv_record, meta_score, results, individual = evo.fitness(individual, json_path)
 
     if results is None:
-        multiprocessing.get_logger().info("log_likelihood results is None %s", individual)
+        multiprocessing.get_logger().info("log_likelihood results is None %s (%s)", individual, util.convert_individual(individual, cache.cache)[0])
         return -numpy.inf, scores, csv_record, meta_score, results, individual
 
     if results is not None and kde_previous is not None:
@@ -114,12 +114,12 @@ def log_posterior(x):
         cache.cache.setup(json_path)
 
     if outside_bounds(theta, cache.cache):
-        multiprocessing.get_logger().info("individual is outside of range %s", theta)
+        multiprocessing.get_logger().info("individual is outside of range %s (%s)", theta, util.convert_individual(theta, cache.cache)[0])
         return -numpy.inf, theta, cache.cache.WORST, [], cache.cache.WORST_META, None, theta
 
     ll, scores, csv_record, meta_score, results, individual = log_likelihood(theta, json_path)
     if results is None:
-        multiprocessing.get_logger().info("log_posterior results is None %s", theta)
+        multiprocessing.get_logger().info("log_posterior results is None %s (%s)", theta, util.convert_individual(theta, cache.cache)[0])
         return -numpy.inf, theta, cache.cache.WORST, [], cache.cache.WORST_META, None, individual
     else:
         return ll, theta, scores, csv_record, meta_score, results, individual
@@ -953,13 +953,7 @@ def get_population(base, size, diff=0.02):
         indexes = numpy.random.choice(new_population.shape[0], size, replace=False)
         multiprocessing.get_logger().info("indexes: %s", indexes)
         new_population = new_population[indexes, :]
-    #change = numpy.random.normal(1.0, 0.01, new_population.shape)
-    #multiprocessing.get_logger().info(
-    #    "Initial population condition number before %s  after %s",
-    #    numpy.linalg.cond(new_population),
-    #    numpy.linalg.cond(new_population * change),
-    #)
-    return new_population #* change
+    return new_population
 
 
 def resetPopulation(checkpoint, cache):
