@@ -145,7 +145,18 @@ def saveExperiments(save_name_base, settings, target, results, directory, file_p
 
         dst = Path(directory, file_pattern % (save_name_base, experimentName))
 
-        if dst.is_file():  # File already exists don't try to write over it
+        same = False
+        if dst.is_file():
+            #load tolerance to see if the files are actually the same
+            sim_dst = Cadet()
+            sim_dst.filename = dst.as_posix()
+            sim_dst.load(paths=['/input/solver/time_integrator',])
+
+            dst_tol = sim_dst.root.input.solver.time_integrator.abstol
+            sim_tol = simulation.root.input.solver.time_integrator.abstol
+            same = sim_tol == dst_tol
+
+        if same:
             return False
         else:
             simulation.filename = dst.as_posix()
@@ -486,22 +497,13 @@ def setupAltFeature(cache, name):
         if baseDir is not None:
             settings["baseDir"] = baseDir.as_posix()
 
-        settings["searchMethod"] = "ScoreTest"
-
-        data = H5()
-        data.filename = resultsOriginal.as_posix()
-        data.load(
-            paths=["/meta_population",]
-        )
-
-        population = convert_population_inputorder(data.root.meta_population, cache)
-
-        settings["seeds"] = [list(i) for i in population]
+        settings["searchMethod"] = "AltScore"
 
         for experiment in settings["experiments"]:
             for feature in experiment["featuresAlt"]:
                 if feature["name"] == name:
                     experiment["features"] = feature["features"]
+            del experiment["featuresAlt"]
 
         new_settings_file = resultDir / settings_file.name
         with new_settings_file.open(mode="w") as json_data:
@@ -619,6 +621,10 @@ def find_opt_poly(x,y, index):
     x = x[indexes]
     y = y[indexes]
 
+    if x[0] > x[-1]:  #need to invert order
+        x = x[::-1]
+        y = y[::-1]
+
     poly, res = numpy.polynomial.Polynomial.fit(x, y,2, full=True)
     root = poly.deriv().roots()[0]
     root = numpy.clip(root, x[0], x[1])
